OiRA

Help

1. It-Tħejjija
2. Involvi
3. L-Identifikazzjoni + Il-Valutazzjoni
4. Il-Pjan ta' Azzjoni
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Riskju preżenti
5. Ir-Rapport
6. Stat 9%

# Commercial guarding, Leicester

Wara li tkun identifikajt ir-riskji, trid tistabbilixxi pjan ta' azzjoni biex timmaniġġja r-riskji. Biex telimina jew tnaqqas ir-riskji, trid tistabbilixxi liema miżuri preventivi u protettivi għandhom jittieħdu.

Fost l-affarijiet li għandhom jiġu kkunsidrati għal dan l-istadju huma:

1. Ir-riskju jista' jiġi evitat? Jista' jitneħħa kompletament? Pereżempju, dan jista' jinkiseb billi:
   - kunsiderazzjoni ta' jekk il-kompitu jew inkarigu huwiex neċessarju
   - tneħħija tal-periklu
2. Jekk ċerti riskji mhumiex evitabbli, kif jistgħu jitnaqqsu għal livell fejn is-saħħa u s-sigurtà ta' dawk esposti ma jiġux kompromessi?

Ladarba tkun iddeċidejt kif telimina jew tnaqqas riskju partikolari, imbagħad tiddeskrivi l-azzjoni(jiet) speċifika/speċifiċi meħtieġa biex jinkiseb dan. Għandek ukoll tinkludi dettalji tal-livell ta' kompetenza u/jew rekwiżiti oħra meħtieġa biex dawk l-azzjonijiet ikunu effettivi.

Oħloq pjan ta' azzjoni

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More